@@ -1045,6 +1045,28 @@ class Resources extends SiteController
 			App::redirect(Route::url($redirect, false), '', '', false);
 		}
 
+		if (!Request::getInt('no_html'))
+		{
+			// Set breadcrumbs
+			Pathway::append(
+				stripslashes($this->model->type->type),
+				Route::url('index.php?option=' . $this->_option . '&type=' . $this->model->type->alias)
+			);
+
+			Pathway::append(
+				stripslashes($this->model->resource->title),
+				Route::url('index.php?option=' . $this->_option . '&id=' . $this->model->resource->id)
+			);
+
+			Pathway::append(
+				Lang::txt('COM_RESOURCES_VIEW_PRESENTATION'),
+				Route::url('index.php?option=' . $this->_option . '&id=' . $this->model->resource->id . '&task=view&resid=' . $child)
+			);
+
+			// Write title
+			Document::setTitle(Lang::txt(strtoupper($this->_option)) . ': ' . stripslashes($this->model->resource->title));
+		}
+
 		// Instantiate a new view
 		$this->view = new \Hubzero\Component\View(array(
 			'name'   => 'view',
@@ -2135,6 +2157,24 @@ class Resources extends SiteController
 			App::abort(404, Lang::txt('COM_RESOURCES_RESOURCE_NOT_FOUND'));
 		}
 
+		// Check if direct access is restricted. If so, look for a token
+		$activeParams = new \Hubzero\Config\Registry($resource->params);
+		$type = new Type($this->database);
+		$type->load($resource->type);
+		$typeParams = new \Hubzero\Config\Registry($type->params);
+		$restrictDirectDownload = $activeParams->get('restrict_direct_access') ? $activeParams->get('restrict_direct_access') : $typeParams->get('restrict_direct_access');
+
+
+		// Check to see if the Google doc viewer is being used and skip checking for the token if that is the case.
+		$referer = Request::server('HTTP_REFERER');
+		$referer = !empty($referer) ? parse_url($referer) : null;
+		$refererHost = !empty($referer['host']) ? strtolower($referer['host']) : null;
+
+		if ($restrictDirectDownload == 2 && $refererHost != 'docs.google.com')
+		{
+			Request::checkToken('get');
+		}
+
 		// Check if the resource is for logged-in users only and the user is logged-in
 		if (($token = Request::getVar('token', '', 'get')))
 		{
@@ -2158,7 +2198,21 @@ class Resources extends SiteController
 		{
 			$user = User::getInstance();
 		}
-		if ($resource->access == 1 && $user->isGuest())
+
+		// Get parent Access level and use it if it is more restrictive
+		if ($resource->standalone != 1)
+		{
+			$helper = new Helper($resource->id, $this->database);
+			$helper->getParents();
+			$parents = $helper->parents;
+			if (count($parents) == 1)
+			{
+				$parent = new Resource($this->database);
+				$parent->load($parents[0]->id);
+			}
+		}
+		$accessLevel = (isset($parent) && ($parent->access > $resource->access)) ? $parent->access : $resource->access;
+		if ($accessLevel == 1 && $user->isGuest())
 		{
 			//App::abort(403, Lang::txt('COM_RESOURCES_ALERTNOTAUTH'));
 			$return = base64_encode(Request::getVar('REQUEST_URI', Route::url('index.php?option=' . $this->_option . '&id=' . $this->id . '&d=' . $d, false, true), 'server'));
@@ -2170,9 +2224,8 @@ class Resources extends SiteController
 		}
 
 		// Check if the resource is "private" and the user is allowed to view it
-		if ($resource->access == 4  // private
-		 || ($resource->access == 3 && $resource->path))  // protected -- We need to allow images in the sbtract to come through
-		// || !$resource->standalone) // child, no direct access
+		if ($accessLevel == 4  // private
+		 || ($accessLevel == 3 && $resource->path))  // protected -- We need to allow images in the sbtract to come through
 		{
 			if ($user->isGuest())
 			{
@@ -2432,6 +2485,11 @@ class Resources extends SiteController
 		$row = new Resource($this->database);
 		$row->load($id);
 
+		if (!$row->id)
+		{
+			App::abort(404, Lang::txt('COM_RESOURCES_RESOURCE_NOT_FOUND'));
+		}
+
 		$thedate = ($row->publish_up != '0000-00-00 00:00:00')
 				 ? $row->publish_up
 				 : $row->created;
@@ -2762,6 +2820,7 @@ class Resources extends SiteController
 				}
 			}
 		}
+
 		if (!$resource->standalone)
 		{
 			if (!isset($p) && isset($parents) && count($parents) == 1)
