@@ -674,7 +674,6 @@ class Tickets extends SiteController
 			{
 				$filters['search'] = '';
 			}
-
 			$query->query = $sq->getQuery($query->conditions);
 
 			// Get a record count
@@ -894,8 +893,6 @@ class Tickets extends SiteController
 
 			$lists['severities'] = Utilities::getSeverities($this->config->get('severities'));
 
-			$sr = new Tables\Resolution($this->database);
-			$lists['resolutions'] = $sr->getResolutions();
 
 			$sc = new Tables\Category($this->database);
 			$lists['categories'] = $sc->find('list');
@@ -1677,9 +1674,6 @@ class Tickets extends SiteController
 
 		$this->view->lists = array();
 
-		// Get resolutions
-		$sr = new Tables\Resolution($this->database);
-		$this->view->lists['resolutions'] = $sr->getResolutions();
 
 		$sc = new Tables\Category($this->database);
 		$this->view->lists['categories'] = $sc->find('list');
@@ -2376,7 +2370,7 @@ class Tickets extends SiteController
 			$row->set('severity', ($row->get('severity') ? $row->get('severity') : 'normal'));
 			$row->set('category', ($row->get('category') ? $row->get('category') : Lang::txt('COM_SUPPORT_CATEGORY_TOOLS')));
 			$row->set('resolved', '');
-			$row->set('email', ($row->get('email') ? $row->get('email') : $this->_data['supportemail']));
+			$row->set('email', ($row->get('email') ? $row->get('email') : Config::get('mailfrom')));
 			$row->set('name', ($row->get('name') ? $row->get('name') : Lang::txt('COM_SUPPORT_AUTOMATED_REPORT')));
 			$row->set('cookies', ($row->get('cookies') ? $row->get('cookies') : 1));
 			$row->set('instances', 1);
@@ -2390,7 +2384,10 @@ class Tickets extends SiteController
 				return;
 			}
 
-			$row->tag($incoming['tags'], User::get('id'), 1);
+			if (isset($incoming['tags']))
+			{
+				$row->tag($incoming['tags'], User::get('id'), 1);
+			}
 
 			if ($attachment = $this->uploadTask($row->get('id')))
 			{
